@@ -4,14 +4,13 @@
 #include "spvm_base.h"
 
 enum {
+  SPVM_DESCRIPTOR_C_ID_INTERFACE,
+  SPVM_DESCRIPTOR_C_ID_VALUE_T,
+  SPVM_DESCRIPTOR_C_ID_POINTER_T,
   SPVM_DESCRIPTOR_C_ID_NATIVE,
   SPVM_DESCRIPTOR_C_ID_PRECOMPILE,
-  SPVM_DESCRIPTOR_C_ID_CONST,
-  SPVM_DESCRIPTOR_C_ID_INTERFACE,
   SPVM_DESCRIPTOR_C_ID_PUBLIC,
   SPVM_DESCRIPTOR_C_ID_PRIVATE,
-  SPVM_DESCRIPTOR_C_ID_POINTER,
-  SPVM_DESCRIPTOR_C_ID_VALUE_T,
   SPVM_DESCRIPTOR_C_ID_RW,
   SPVM_DESCRIPTOR_C_ID_RO,
   SPVM_DESCRIPTOR_C_ID_WO,
